package
Version:
v0.0.0-...-8199c21
Opens a new window with list of versions in this module.
Published: Mar 18, 2026
License: GPL-3.0
Opens a new window with license information.
Imports: 1
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
func NilCheck[T any](t *T, constructor func() *T) *T
NilCheck returns t if it is not nil and invokes the constructor if it is.
func Tern[T any](cond bool, a, b T) T
Tern implements ternary operator.
BitFlag supports bit flag operations.
NewFlag creates a BitFlag
Source Files
¶
Click to show internal directories.
Click to hide internal directories.